'''
Frame with multiple check boxes for Tkinter Py3
Author: jean-claude.feltes@education.lu

Usage:
    c=Checkbar(parent, txts)                  # for horizontal alignmant
    c=Checkbar(parent, txts, side=tk.TOP)     3 for vertical alignment

        parent is the parent window
        txts is an array containing the check box labels 
        optional parameters: side, anchor
    
    c.setstate(states): set the initial state (states = e.g. [0,1,1]
    states = c.getstate() reads the actual state
'''
import tkinter as tk





class Checkbar(tk.Frame):
    '''Frame with Multiple check boxes for Tkinter Py3'''
    def __init__(self, parent, texts=[], side=tk.LEFT, anchor=tk.W):
        
        tk.Frame.__init__(self, parent)
        self.vars=[]
        self.buttons=[]
        for txt in texts:
            var = tk.IntVar()
            chk = tk.Checkbutton(self, text=txt, variable=var)
            chk.pack(side=side, anchor=anchor, expand=tk.YES)
            self.vars.append(var)
            self.buttons.append(chk)
                
    def getstate(self):
        """returns states as array e.g. [0,1,1]"""
        v = [var.get() for var in self.vars]
        return v
                  
    def setstate(self, states):
        """sets states of buttons, states given as array e.g. [1,1,0]"""
        i=0
        for st in states:
            self.vars[i].set(st)
            i+=1
        
        
        
    
#-----------------------------------------------------------------
# Test

if __name__ == '__main__':
    def printstates():
        print (c.getstate())
    
    root=tk.Tk()
    txts=["CH0", "CH1", "All channels"]
    
    c=Checkbar(root, txts)
    #c=Checkbar(root, txts, side=tk.TOP)
    c.setstate([1,0,1])
    c.config(relief=tk.RIDGE, bd=3)
    c.pack()
    
    b=tk.Button(root, text="Print", command=printstates)
    b.pack()
    
    root.mainloop()

