""" Custom dialog for Tkinter, Python 3
Author: jean.-claude.feltes@education.lu

Usage:
    t = MyDialog(title, label, presettext)
    t = MyDialog(title)
waits until:
        Return / Enter / OK button -> returns input
        Escape -> returns ''
"""     

from tkinter import *

def MyDialog (title, labeltext="", text=""):
    """function MyDialog(title, labeltext, text)""" 
    d = _MyDialog(title, labeltext, text)
    d. wait()
    return d.get()
        

class _MyDialog:
    """internal class for MyDialog"""

    def __init__(self, title, labeltext="", text=""):

        top = self.top = Toplevel()
        top.title(title)
        top.grab_set()
        top.attributes("-topmost", True)
        
        Label(top, text=labeltext).pack()
        
        self.e = Entry(top)
        self.e.insert(INSERT, text)
        self.e.pack(padx=5)
        self.e.focus_set()
        self.e.bind('<Return>', self.on_Return)          # normal Return / Enter   
        self.e.bind('<KP_Enter>', self.on_Return)        # Enter on numeric keypad   
        self.e.bind('<Escape>', self.on_Escape)
                

        b = Button(top, text="OK", command=self.on_ok)
        b.pack(pady=5)
        
        self.text=""
        
    def on_Return(self, event):
        # reaction to <Enter> / <Return>
        self.on_ready()
        
    def on_Escape(self, event):
        # reaction to <Escape>  -> clear
        self.e.delete(0, END)
        self.on_ready()    
      
               
    def on_ok(self):
        # reaction to OK button
        self.on_ready()
        
    def get(self):
        # get entered text
        return self.text
        
        
    def on_ready(self):
        # when ready: get text and destroy window
        self.text=self.e.get() 
        self.top.destroy()    
        
    def wait(self):
        # wait for user input
        self.top.wait_window()  

#---------------------------------------------------

if __name__ == "__main__":
    root = Tk()
    
    
    t = MyDialog("TEST", "values", "12,23")
    print(t)
    
    root.mainloop()
    
