""" Custom multi dialog for Tkinter, Python 3
    with labels and text fields
    
    Author: jean-claude.feltes@education.lu
    
usage:
    t = MultiDialog(title, labels, presettexts)
    or
    t = MultiDialog(title, labels)
labels and presettexts are string arrays
The number of input fields is determined by len(labels)    
waits until:
        OK      -> returns input as array
        Cancel  -> returns empty array
"""     

from tkinter import *

minimumlength=10        # min. textfield length

#----------------------------------------------------------------
def getlength(text):
    """get length of entry fields
    with a minimum length
    and max. length according to longest text[i]
    """
    
    for t in text:
        lmax= minimumlength
        if len(t)>lmax:
            lmax=len(t)
    return lmax

#------------------------------------------------------------------                

def MultiDialog (title, labeltext=[], text=[]):
    """ main function for multiple dialog"""
    d = _MultiDialog(title, labeltext, text)
    d. wait()
    return d.get()
        

class _MultiDialog:
    """internal class for MultiDialog"""

    def __init__(self, title, labeltext, text=[]):
        
        top = self.top = Toplevel()
        ##top.geometry("500x100")
        top.title(title)
        top.grab_set()
        top.attributes("-topmost", True)                # always on top!
        
        mainframe=Frame(top)
        leftframe = Frame(mainframe)
        for l in labeltext:
            Label(leftframe, text=l).pack(side=TOP, pady=2)
        leftframe.pack(side=LEFT)    
       
        rightframe = Frame(mainframe)
        i=0
        self.e=[]
        for l in labeltext: 
            self.e.append( Entry(rightframe))
            try:    #text[] may be empty, so it's better to try
                self.e[i].insert(INSERT, text[i])
            except:
                pass    
            
            # max.length of text
            lmax = getlength(text)
            self.e[i].config(width=lmax)
            self.e[i].pack(padx=5)
            i+=1
        rightframe.pack(side=LEFT)
        
        mainframe.pack(side=TOP)    
        
        # buttons
        buttonframe=Frame(top)
        b1 = Button(buttonframe, text="Cancel", command=self.on_cancel)
        b1.pack(side=LEFT, pady=5)
        b2 = Button(buttonframe, text="OK", command=self.on_ok)
        b2.pack(side=LEFT, pady=5)
        buttonframe.pack()
   
        self.texts=[]
        
        
    def on_cancel(self):
        # reaction to <Escape>  -> clear
        self.texts=[]
        self.top.destroy()    
     
               
    def on_ok(self):
        # reaction to OK button
        self.on_ready()
        
    def get(self):
        # get entered text
        return self.texts
        
        
    def on_ready(self):
        # when ready: get text and destroy window
        t=[]
        i=0
        for l in labels:
            t.append(self.e[i].get())
            i+=1
        self.texts=t 
        self.top.destroy()    
        
    def wait(self):
        # wait for user input
        self.top.wait_window()  

#---------------------------------------------------

if __name__ == "__main__":
    root = Tk()
    
    labels=["label1", "label2", "label3", "Veryveryverylonglabel_l4", "LONGLabel5"]
    text=["t1", "t2", "t    3", "text5", "veryveryverrrrrrrrrylongtextt6"]
    
    t = MultiDialog("TEST", labels, text)
    #t = MultiDialog("TEST", labels)
    print(t)
    
    root.mainloop()
    
